<?php

namespace Drupal\paid_ads\Plugin;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Plugin\PluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Base class for Paid gateways plugins.
 */
abstract class PaidGatewaysPluginBase extends PluginBase implements PaidGatewayInterface, ContainerFactoryPluginInterface {

  /**
   * Drupal logger.
   *
   * @var \Drupal\Core\Logger\LoggerChannel
   */
  protected $logger;

  /**
   * ConfigFactory injection.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $configurationStorage;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('config.factory'),
      $container->get('logger.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, string $plugin_id, $plugin_definition, ConfigFactoryInterface $config, LoggerChannelFactoryInterface $logger) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->configurationStorage = $config->getEditable('paid_ads.gateways');
    $this->logger = $logger->get($plugin_id);
  }

  /**
   * {@inheritdoc}
   */
  abstract public function getForm(array $option);

  /**
   * Returns a config key for storing the plugin settings.
   *
   * @return string
   *   Name of the used config.
   */
  protected function getConfigName() {
    return 'paid_ads.gateways.' . $this->getPluginId();
  }

  /**
   * {@inheritdoc}
   *
   * @todo Why it's needed?
   */
  public function getConfigForm(array $form, FormStateInterface $form_state) {
    return [
      'form' => $this->buildConfigurationForm($form, $form_state),
      '#tree' => TRUE,
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Save'),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function setOptions(array $options = []) {
    $this->configurationStorage->set($this->getConfigName(), $options)
      ->save();
  }

  /**
   * {@inheritdoc}
   */
  public function getOptions() {
    return $this->configurationStorage->get($this->getConfigName()) ?? [];
  }

  /**
   * {@inheritdoc}
   */
  abstract public function onCreatePayment(array $context);

  /**
   * {@inheritdoc}
   */
  abstract public function onApprovePayment(array $context);

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(array &$form, FormStateInterface $form_state) {
  }

}
